from django.conf import urls
from django.urls import path, re_path
from django.views.i18n import JavaScriptCatalog
from django.views.decorators.cache import cache_page

from fotos import views

urls.handler404 = views.handler404

urlpatterns = [
    re_path(r'^$', views.index, name='index'),

    re_path(r'^(\d{4})/(\d{2})/([\w-]+)/([\w\.-]+)/?$', views.photo, name='photo'),
    re_path(r'^(\d{4})/(\d{2})/([\w-]+)/?$', views.event, name='event'),
    re_path(r'^(\d{4})/(\d{2})/?$', views.month, name='month'),
    re_path(r'^(\d{4})/?$', views.year, name='year'),
    re_path(r'^search/?$', views.search, name='search'),
    re_path(r'^result/?$', views.result, name='result'),

    re_path(r'^admin/info/?', views.info, name='info'),
    re_path(r'^admin/password/?', views.password, name='password'),
    re_path(r'^admin/api/?', views.api, name='api'),
    re_path(r'^admin/download-covers/?',
            views.download_covers, name='download-covers'),
    re_path(r'^admin/upload-covers/?',
            views.upload_covers, name='upload-covers'),
    re_path(r'^admin/upload/?', views.upload, name='upload'),
    re_path(r'^admin/map/?', views.map, name='map'),
    re_path(r'^admin/reset/?', views.reset, name='reset'),
    re_path(r'^admin/set-cover/?', views.set_cover, name='set-cover'),
    re_path(r'^admin/private/?', views.private, name='private'),
    re_path(r'^admin/public/?', views.public, name='public'),
    re_path(r'^admin/delete/?', views.delete, name='delete'),
    re_path(r'^admin/logout/?', views.logout, name='logout'),
    re_path(r'^admin/login/?', views.login, name='login'),

    re_path(r'^rest/list-albums/?$',
            views.list_albums, name='list-albums'),
    re_path(r'^rest/list-photos/?$',
            views.list_photos, name='list-photos'),
    re_path(r'^rest/random-photo/?$',
            views.random_photo, name='random-photo'),
    re_path(r'^rest/upload-photos/?$',
            views.upload_photos, name='upload-photos'),
    re_path(r'^rest/delete-item/?$',
            views.delete_item, name='delete-item'),
    re_path(r'^rest/reset-covers/?$',
            views.reset_covers, name='reset-covers'),
    re_path(r'^rest/get-covers/?$',
            views.get_covers, name='get-covers'),
    re_path(r'^rest/set-covers/?$',
            views.set_covers, name='set-covers'),

    path('jsi18n/',
         cache_page(86400)(JavaScriptCatalog.as_view()),
         name='javascript-catalog'),
]
