"""
Django settings for galeria project.

Generated by 'django-admin startproject' using Django 3.2.8.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

import os
import os.path

from pathlib import Path
from datetime import datetime

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
# Generate with django-admin startproject or with Python secrets module
SECRET_KEY = ''

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True
DEBUG_PROPAGATE_EXCEPTIONS = True

ALLOWED_HOSTS = [ '127.0.0.1', 'localhost', YOUR_HOST ]

# Application definition

INSTALLED_APPS = [
    'fotos.apps.FotosConfig',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.humanize',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'rest_framework',
    'rest_framework.authtoken',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'galeria.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'galeria.wsgi.application'


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'OPTIONS': {
            'read_default_file': os.path.join(BASE_DIR, 'galeria/mysql.cnf'),
            'init_command': 'SET foreign_key_checks = 0;',
        }
    }
}


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = 'en-US'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = False

USE_TZ = True

# Change it accordingly
HOME = os.getenv('HOME')

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'

LOCALE_PATHS = [ os.path.join(BASE_DIR, 'locale') ]

# Chante to True to run the django server
RUN_DJANGO_SERVER = False

if RUN_DJANGO_SERVER:
    # Static files (CSS, JavaScript, Images)
    # https://docs.djangoproject.com/en/3.2/howto/static-files/
    STATIC_URL = '/static/'
    PREFIX = ''
    STATIC_URL_PREFIX = '/static/public'
else:
    # Static files (CSS, JavaScript, Images)
    # https://docs.djangoproject.com/en/3.2/howto/static-files/
    STATIC_URL = '/galeria/static/'
    PREFIX = '/galeria'
    STATIC_URL_PREFIX = '/' # /~user, for example

LOGIN_URL = os.path.join(PREFIX, 'admin/login')

STATIC_PATH_PREFIX = os.path.join(HOME, 'public_html')
GALERIA_PREFIX = os.path.join(STATIC_PATH_PREFIX, 'galeria/photos')
# The TMP dir cannot be absolute
UPLOAD_TMP_DIR = os.path.join(HOME, '.tmp/galeria-images')[1:]

PAGINATION_ITEMS = 12
LIST_ITEMS = 100

EXPORT_WIDTH = 490
THUMB_MAX = 400
VIEW_MAX = 840

GALERIA_INFO = { 'title': 'Your title',
                 'subtitle': 'Your subtitle',
                 'owner': 'Your name',
                 'email': 'your@email.com',
                 'first_year': 1900, # Start of copyright
                 'now_year': datetime.now().year,
                 'items_per_page': PAGINATION_ITEMS }

ALBUMS_ORDER = 'descendant' # Or 'ascendant'
PHOTOS_ORDER = 'ascendant' # Or 'descendant'

# Mexico City; change it to whatever you want
DEFAULT_LATITUDE = 19.433333333
DEFAULT_LONGITUDE = -99.133333333

REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': [
        'rest_framework.authentication.TokenAuthentication',
    ]
}
